@@ -190,7 +190,7 @@ new_file_ok_cb (GtkWidget *w,
 		dialog = _gtk_message_dialog_new (GTK_WINDOW (window->app),
 						  GTK_DIALOG_MODAL,
 						  GTK_STOCK_DIALOG_QUESTION,
-						  _("Archive already exists.  Do you want to overwrite it ?"),
+						  _("Archive already exists.  Do you want to overwrite it?"),
 						  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 						  _("Overwrite"), GTK_RESPONSE_YES,
 						  NULL);
@@ -245,8 +245,7 @@ new_archive_cb (GtkWidget *widget,
 {
 	FRWindow  *window = data;
 	GtkWidget *file_sel;
-	GtkWidget *frame;
-	GtkWidget *vbox;
+	GtkWidget *hbox;
 	GtkWidget *opt_menu;
 	GtkWidget *menu;
 	char      *dir;
@@ -259,20 +258,19 @@ new_archive_cb (GtkWidget *widget,
 
 	/**/
 
-	frame = gtk_frame_new (_("File type :"));
-	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-	gtk_box_pack_start (GTK_BOX (GTK_FILE_SELECTION (file_sel)->action_area), frame, TRUE, TRUE, 0);
+	hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (GTK_FILE_SELECTION (file_sel)->action_area), hbox, TRUE, TRUE, 0);
 
-	vbox = gtk_vbox_new (FALSE, 5);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
-	gtk_container_add (GTK_CONTAINER (frame), vbox);
+	gtk_box_pack_start (GTK_BOX (hbox), 
+			    gtk_label_new (_("Archive type:")),
+			    FALSE, FALSE, 0);
 
 	opt_menu = gtk_option_menu_new ();
 	menu = build_file_type_menu (window);
         gtk_option_menu_set_menu (GTK_OPTION_MENU (opt_menu), menu);
 	gtk_widget_show (opt_menu);
-	gtk_box_pack_start (GTK_BOX (vbox), opt_menu, FALSE, FALSE, 5);
-
+	gtk_box_pack_start (GTK_BOX (hbox), opt_menu, FALSE, FALSE, 12);
+	
 	/**/
 
 	g_object_set_data (G_OBJECT (file_sel), "fr_window", window);
@@ -419,7 +417,7 @@ copy_archive_ok_cb (GtkWidget    *w,
 		d = _gtk_message_dialog_new (GTK_WINDOW (window->app),
 					     GTK_DIALOG_MODAL,
 					     GTK_STOCK_DIALOG_QUESTION,
-					     _("Archive already exists.  Do you want to overwrite it ?"),
+					     _("Archive already exists.  Do you want to overwrite it?"),
 					     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					     _("Overwrite"), GTK_RESPONSE_YES,
 					     NULL);
@@ -535,7 +533,7 @@ remove_extension (const char *filename)
 {
 	const char *ext;
 
-	ext = fr_archive_utils_get_file_name_ext (filename);
+	ext = fr_archive_utils__get_file_name_ext (filename);
 	if (ext == NULL)
 		return g_strdup (filename);
 	else
@@ -577,7 +575,7 @@ rename_archive_cb (GtkWidget *widget,
 	new_filename = g_strconcat (dir, 
 				    "/", 
 				    file_name_from_path (string),
-				    fr_archive_utils_get_file_name_ext (window->archive->filename),
+				    fr_archive_utils__get_file_name_ext (window->archive->filename),
 				    NULL);
 	g_free (dir);
 	g_free (string);
@@ -589,7 +587,7 @@ rename_archive_cb (GtkWidget *widget,
 		d = _gtk_message_dialog_new (GTK_WINDOW (window->app),
 					     GTK_DIALOG_MODAL,
 					     GTK_STOCK_DIALOG_QUESTION,
-					     _("Archive already exists.  Do you want to overwrite it ?"),
+					     _("Archive already exists.  Do you want to overwrite it?"),
 					     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					     _("Overwrite"), GTK_RESPONSE_YES,
 					     NULL);
@@ -628,7 +626,7 @@ delete_archive_cb (GtkWidget *widget,
 	dialog = _gtk_message_dialog_new (GTK_WINDOW (window->app),
 					  GTK_DIALOG_MODAL,
 					  GTK_STOCK_DIALOG_QUESTION,
-					  _("Archive will be deleted, are you sure ?"),
+					  _("Archive will be deleted, are you sure?"),
 					  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					  GTK_STOCK_DELETE, GTK_RESPONSE_YES,
 					  NULL);
@@ -787,9 +785,9 @@ about_cb (GtkWidget *widget,
 	}
 
 	logo = gdk_pixbuf_new_from_file (PIXMAPSDIR "/file-roller.png", NULL);
-	about = gnome_about_new ("File Roller", 
+	about = gnome_about_new (_("File Roller"), 
 				 VERSION,
-				 "Copyright (C) 2001 The Free Software Foundation, Inc.",
+				 "Copyright \xc2\xa9 2001-2002 Free Software Foundation, Inc.",
 				 _("An archive manager for GNOME."),
 				 authors,
 				 documenters,
